import argparse
import const as THE


def get_parsed():
    parser = argparse.ArgumentParser()
    parser.add_argument("-v", "--version", action="version", version=THE.VERSION)
    parser.add_argument(
        "-f",
        "--file",
        action="store",
        dest="source",
        default="",
        help="location of source file",
    )
    parser.add_argument(
        "-t",
        "--telescope",
        action="store_const",
        dest="source",
        const="TELESCOPE",
        help="check recent posts indexed by Telescope",
    )
    parser.add_argument(
        "-r",
        "--rtf",
        action="store_const",
        dest="output",
        const="rtf",
        default=THE.OUTPUT,
        help="output as rich text file",
    )
    parser.add_argument(
        "-j",
        "--json",
        action="store_const",
        dest="output",
        const="json",
        help="output as json",
    )
    parser.add_argument(
        "-a",
        "--all",
        action="store_const",
        dest="wanted",
        const=THE.ALL,
        default=THE.ALL,
        help="output includes all results",
    )
    parser.add_argument(
        "-g",
        "--good",
        action="store_const",
        dest="wanted",
        const=[THE.GOOD],
        help="output includes only [GOOD] results",
    )
    parser.add_argument(
        "-b",
        "--bad",
        action="store_const",
        dest="wanted",
        const=[THE.FAIL],
        help="output includes only [FAIL] results",
    )
    parser.add_argument(
        "-i", "--ignore", action="store", dest="ignore", help="location of ignore file"
    )
    return parser.parse_args()



import sys
import const as THE


def std_format(status):
    return f'[{status["desc"]}] [{status["code"]}] {status["url"]}'


def json_format(status):
    return '{"url": \'' + status["url"] + '\', "status": ' + str(status["code"]) + "}"


def rtf_format(status):
    color = r"\cf2"  # grey
    if status["desc"] == THE.GOOD:
        color = r"\cf4"  # green
    elif status["desc"] == THE.FAIL:
        color = r"\cf3"  # red
    return f'{color} [{status["code"]}] [{status["desc"]}] {status["url"]}'


# standard output
def to_console(results, output):
    print(results) if output == "json" else print("\n".join(results))


# creates an rtf file and writes results
def to_rtf(results, output):
    try:
        with open("output.rtf", "w") as rtf_file:
            rtf_file.write(THE.RTF + "\\\n".join(results) + "}")
            print("output.rtf is ready")
    except:
        print("error writing list")
        sys.exit(1)



VERSION = "***** Get-Url-Status (GUS) Text-As-Visual-Output (TAVO) ***** version 0.1.6"

# all urls starting with http:// or https:// including leading char in case url is nested
ALL_URLS_REGEX = r".?http[s]?://[a-zA-Z0-9- _.~!*\'();:@&=+$,/?%#[\]]+."
IGNORE_URLS_REGEX = r"^https?://.*[^\s/]"  # line starts with http:// or https://
COMMENTS_REGEX = r"^#.*"  # line starts with #
DOMAIN_REGEX = r"(?<!/|:)/"

NESTED = {"(": ")", "[": "]", ">": "<", '"': '"'}

OUTPUT = "std"
RTF = """{\\rtf1\\ansi\\ansicpg1252\\cocoartf2513\\cocoatextscaling0\\cocoaplatform0{\\fonttbl\\f0\\fswiss\\fcharset0 Helvetica;}
{\\colortbl;\\red255\\green255\\blue255;\\red87\\green87\\blue87;\\red252\\green41\\blue19;\\red159\\green242\\blue92;}
{\\*\\expandedcolortbl;;\\cssrgb\\c41531\\c41531\\c41531;\\cssrgb\\c100000\\c25745\\c7993;\\cssrgb\\c67668\\c94348\\c43431;}
\\cf0"""

GOOD = "GOOD"
FAIL = "FAIL"
UNKN = "UNKN"
ALL = [GOOD, FAIL, UNKN]



import setuptools

with open(".github/README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="gustavo",
    version="1.0.1",
    author="Anthony Slater",
    author_email="slaterslater@gmail.com",
    description="A small example package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/slaterslater/gustavo",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    py_modules=["args", "const", "out", "urls"],
    install_requires=['requests','progress'],
    entry_points = {
        "console_scripts": [
            "gus = gus.__main__",
        ]
    }
)